"""
Tests for spectra, don't implement now because will fail on 
travis where we haven't set up the full GRIZLI path and reference
files
"""
# import os
# import unittest
# 
# import numpy as np
# from .. import utils, prep, multifit, fitting
# 
# class Dummy(unittest.TestCase):  
#     def test_multibeam(self):
#         path = os.path.dirname(utils.__file__)
#         print(path)
#         mb = multifit.MultiBeam(path+'/tests/data/j033216m2743_00147.beams.fits', group_name='j033216m2743', MW_EBV=-1, fcontam=0.1, sys_err=0.03)
#         

